"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const e_1 = require("e");
const monsterData_1 = require("../meta/monsterData");
const util_1 = require("../util/util");
const Bank_1 = __importDefault(require("./Bank"));
const Monster_1 = __importDefault(require("./Monster"));
class SimpleMonster extends Monster_1.default {
    constructor(options) {
        let allItems = [];
        if (options.table) {
            allItems = allItems.concat(options.table.allItems);
        }
        if (options.pickpocketTable) {
            allItems = allItems.concat(options.pickpocketTable.allItems);
        }
        super(Object.assign(Object.assign({}, options), { allItems }));
        Object.defineProperty(this, "table", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "onTaskTable", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "wildyCaveTable", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "pickpocketTable", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "customKillLogic", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.table = options.table;
        this.pickpocketTable = options.pickpocketTable;
        this.onTaskTable = options.onTaskTable;
        this.wildyCaveTable = options.wildyCaveTable;
        this.customKillLogic = options.customKillLogic;
    }
    kill(quantity = 1, options = {}) {
        var _a, _b;
        const loot = new Bank_1.default();
        const canGetBrimKey = options.onSlayerTask && options.slayerMaster === monsterData_1.MonsterSlayerMaster.Konar;
        const wildySlayer = options.onSlayerTask && options.slayerMaster === monsterData_1.MonsterSlayerMaster.Krystilia;
        const slayerMonster = Boolean(options.onSlayerTask && this.data.slayerLevelRequired > 1);
        for (let i = 0; i < quantity; i++) {
            if (canGetBrimKey) {
                if ((0, e_1.roll)((0, util_1.getBrimKeyChanceFromCBLevel)(this.data.combatLevel))) {
                    loot.add("Brimstone key");
                }
            }
            if (wildySlayer && this.data.hitpoints) {
                if ((0, e_1.roll)((0, util_1.getSlayersEnchantmentChanceFromHP)(this.data.hitpoints))) {
                    loot.add("Slayer's enchantment");
                }
                if ((0, e_1.roll)((0, util_1.getLarranKeyChanceFromCBLevel)(this.data.combatLevel, slayerMonster))) {
                    loot.add("Larran's key");
                }
            }
            if (options.inCatacombs && this.data.hitpoints && !wildySlayer) {
                if ((0, e_1.roll)((0, util_1.getAncientShardChanceFromHP)(this.data.hitpoints))) {
                    loot.add("Ancient shard");
                }
                if ((0, e_1.roll)((0, util_1.getTotemChanceFromHP)(this.data.hitpoints))) {
                    // Always drop Dark totem base and bot will transmog accordingly.
                    loot.add("Dark totem base");
                }
            }
            if (options.onSlayerTask) {
                if (wildySlayer && this.wildyCaveTable) {
                    // Roll the monster's wildy slayer cave table
                    loot.add(this.wildyCaveTable.roll(1, options.lootTableOptions));
                }
                else if (this.onTaskTable) {
                    // Roll the monster's "on-task" table.
                    loot.add(this.onTaskTable.roll(1, options.lootTableOptions));
                }
                else {
                    // Monster doesn't have a unique on-slayer table
                    loot.add((_a = this.table) === null || _a === void 0 ? void 0 : _a.roll(1, options.lootTableOptions));
                }
            }
            else {
                // Not on slayer task
                loot.add((_b = this.table) === null || _b === void 0 ? void 0 : _b.roll(1, options.lootTableOptions));
            }
            if (this.customKillLogic) {
                this.customKillLogic(options, loot);
            }
        }
        return loot;
    }
}
exports.default = SimpleMonster;
//# sourceMappingURL=SimpleMonster.js.map